==> chaosmesh-model-5.7.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/AwsChaosSpec.java <==

package io.fabric8.chaosmesh.v1alpha1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "action",
    "awsRegion",
    "deviceName",
    "duration",
    "ec2Instance",
    "endpoint",
    "scheduler",
    "secretName",
    "volumeID"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = true, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class AwsChaosSpec implements KubernetesResource
{

    @JsonProperty("action")
    private java.lang.String action;
    @JsonProperty("awsRegion")
    private java.lang.String awsRegion;
    @JsonProperty("deviceName")
    private String deviceName;
    @JsonProperty("duration")
    private String duration;
    @JsonProperty("ec2Instance")
    private java.lang.String ec2Instance;
    @JsonProperty("endpoint")
    private String endpoint;
    @JsonProperty("scheduler")
    private SchedulerSpec scheduler;
    @JsonProperty("secretName")
    private String secretName;
    @JsonProperty("volumeID")
    private String volumeID;
    @JsonIgnore
    private Map<java.lang.String, Object> additionalProperties = new HashMap<java.lang.String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public AwsChaosSpec() {
    }

    /**
     * 
     * @param duration
     * @param scheduler
     * @param awsRegion
     * @param endpoint
     * @param secretName
     * @param ec2Instance
     * @param volumeID
     * @param action
     * @param deviceName
     */
    public AwsChaosSpec(java.lang.String action, java.lang.String awsRegion, String deviceName, String duration, java.lang.String ec2Instance, String endpoint, SchedulerSpec scheduler, String secretName, String volumeID) {
        super();
        this.action = action;
        this.awsRegion = awsRegion;
        this.deviceName = deviceName;
        this.duration = duration;
        this.ec2Instance = ec2Instance;
        this.endpoint = endpoint;
        this.scheduler = scheduler;
        this.secretName = secretName;
        this.volumeID = volumeID;
    }

    @JsonProperty("action")
    public java.lang.String getAction() {
        return action;
    }

    @JsonProperty("action")
    public void setAction(java.lang.String action) {
        this.action = action;
    }

    @JsonProperty("awsRegion")
    public java.lang.String getAwsRegion() {
        return awsRegion;
    }

    @JsonProperty("awsRegion")
    public void setAwsRegion(java.lang.String awsRegion) {
        this.awsRegion = awsRegion;
    }

    @JsonProperty("deviceName")
    public String getDeviceName() {
        return deviceName;
    }

    @JsonProperty("deviceName")
    public void setDeviceName(String deviceName) {
        this.deviceName = deviceName;
    }

    @JsonProperty("duration")
    public String getDuration() {
        return duration;
    }

    @JsonProperty("duration")
    public void setDuration(String duration) {
        this.duration = duration;
    }

    @JsonProperty("ec2Instance")
    public java.lang.String getEc2Instance() {
        return ec2Instance;
    }

    @JsonProperty("ec2Instance")
    public void setEc2Instance(java.lang.String ec2Instance) {
        this.ec2Instance = ec2Instance;
    }

    @JsonProperty("endpoint")
    public String getEndpoint() {
        return endpoint;
    }

    @JsonProperty("endpoint")
    public void setEndpoint(String endpoint) {
        this.endpoint = endpoint;
    }

    @JsonProperty("scheduler")
    public SchedulerSpec getScheduler() {
        return scheduler;
    }

    @JsonProperty("scheduler")
    public void setScheduler(SchedulerSpec scheduler) {
        this.scheduler = scheduler;
    }

    @JsonProperty("secretName")
    public String getSecretName() {
        return secretName;
    }

    @JsonProperty("secretName")
    public void setSecretName(String secretName) {
        this.secretName = secretName;
    }

    @JsonProperty("volumeID")
    public String getVolumeID() {
        return volumeID;
    }

    @JsonProperty("volumeID")
    public void setVolumeID(String volumeID) {
        this.volumeID = volumeID;
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(java.lang.String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> chaosmesh-model-5.7.4-sources.jar: io/fabric8/chaosmesh/v1alpha1/AwsChaosSpec.java <==

package io.fabric8.chaosmesh.v1alpha1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "action",
    "awsRegion",
    "deviceName",
    "duration",
    "ec2Instance",
    "endpoint",
    "scheduler",
    "secretName",
    "volumeID"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class AwsChaosSpec implements KubernetesResource
{

    @JsonProperty("action")
    private java.lang.String action;
    @JsonProperty("awsRegion")
    private java.lang.String awsRegion;
    @JsonProperty("deviceName")
    private String deviceName;
    @JsonProperty("duration")
    private String duration;
    @JsonProperty("ec2Instance")
    private java.lang.String ec2Instance;
    @JsonProperty("endpoint")
    private String endpoint;
    @JsonProperty("scheduler")
    private SchedulerSpec scheduler;
    @JsonProperty("secretName")
    private String secretName;
    @JsonProperty("volumeID")
    private String volumeID;
    @JsonIgnore
    private Map<java.lang.String, Object> additionalProperties = new HashMap<java.lang.String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public AwsChaosSpec() {
    }

    /**
     * 
     * @param duration
     * @param scheduler
     * @param awsRegion
     * @param endpoint
     * @param secretName
     * @param ec2Instance
     * @param volumeID
     * @param action
     * @param deviceName
     */
    public AwsChaosSpec(java.lang.String action, java.lang.String awsRegion, String deviceName, String duration, java.lang.String ec2Instance, String endpoint, SchedulerSpec scheduler, String secretName, String volumeID) {
        super();
        this.action = action;
        this.awsRegion = awsRegion;
        this.deviceName = deviceName;
        this.duration = duration;
        this.ec2Instance = ec2Instance;
        this.endpoint = endpoint;
        this.scheduler = scheduler;
        this.secretName = secretName;
        this.volumeID = volumeID;
    }

    @JsonProperty("action")
    public java.lang.String getAction() {
        return action;
    }

    @JsonProperty("action")
    public void setAction(java.lang.String action) {
        this.action = action;
    }

    @JsonProperty("awsRegion")
    public java.lang.String getAwsRegion() {
        return awsRegion;
    }

    @JsonProperty("awsRegion")
    public void setAwsRegion(java.lang.String awsRegion) {
        this.awsRegion = awsRegion;
    }

    @JsonProperty("deviceName")
    public String getDeviceName() {
        return deviceName;
    }

    @JsonProperty("deviceName")
    public void setDeviceName(String deviceName) {
        this.deviceName = deviceName;
    }

    @JsonProperty("duration")
    public String getDuration() {
        return duration;
    }

    @JsonProperty("duration")
    public void setDuration(String duration) {
        this.duration = duration;
    }

    @JsonProperty("ec2Instance")
    public java.lang.String getEc2Instance() {
        return ec2Instance;
    }

    @JsonProperty("ec2Instance")
    public void setEc2Instance(java.lang.String ec2Instance) {
        this.ec2Instance = ec2Instance;
    }

    @JsonProperty("endpoint")
    public String getEndpoint() {
        return endpoint;
    }

    @JsonProperty("endpoint")
    public void setEndpoint(String endpoint) {
        this.endpoint = endpoint;
    }

    @JsonProperty("scheduler")
    public SchedulerSpec getScheduler() {
        return scheduler;
    }

    @JsonProperty("scheduler")
    public void setScheduler(SchedulerSpec scheduler) {
        this.scheduler = scheduler;
    }

    @JsonProperty("secretName")
    public String getSecretName() {
        return secretName;
    }

    @JsonProperty("secretName")
    public void setSecretName(String secretName) {
        this.secretName = secretName;
    }

    @JsonProperty("volumeID")
    public String getVolumeID() {
        return volumeID;
    }

    @JsonProperty("volumeID")
    public void setVolumeID(String volumeID) {
        this.volumeID = volumeID;
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(java.lang.String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
